# Generated by roxygen2: do not edit by hand

export(Bogota_airstations_df)
export(Bogota_business_Date)
export(Bogota_holidays_Date)
export(Bogota_malls_tbl_df)
export(Bucaramanga_wifi_tbl_df)
export(Cannabis_Licenses_tbl_df)
export(Cartagena_wifi_tbl_df)
export(Colombia_coffee_tbl_df)
export(Medellin_rain_tbl_df)
export(Tulua_Public_Schools_tbl_df)
export(admitted_students_df)
export(dead_lianas_df)
export(digital_centers_tbl_df)
export(digital_graduates_tbl_df)
export(foreign_visitors_tbl_df)
export(gdp_departments_tbl_df)
export(get_colombia_airports)
export(get_colombia_attractions)
export(get_colombia_child_mortality)
export(get_colombia_cities)
export(get_colombia_cpi)
export(get_colombia_departments)
export(get_colombia_energy_use)
export(get_colombia_gdp)
export(get_colombia_holidays)
export(get_colombia_hospital_beds)
export(get_colombia_invasive_species)
export(get_colombia_life_expectancy)
export(get_colombia_literacy_rate)
export(get_colombia_native_communities)
export(get_colombia_natural_areas)
export(get_colombia_population)
export(get_colombia_presidents)
export(get_colombia_radios)
export(get_colombia_regions)
export(get_colombia_typical_dishes)
export(get_colombia_unemployment)
export(indigenous_vocabulary_df)
export(municipalities_tbl_df)
export(school_levels_df)
export(vehicle_count_tbl_df)
export(view_datasets_ColombiAPI)
importFrom(dplyr,as_tibble)
importFrom(dplyr,mutate)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(jsonlite,fromJSON)
importFrom(scales,comma)
importFrom(tibble,tibble)
